==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/es/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'						=> 'Se guardaron los datos correctamente',
'L_UPDATE_TITLE'						=> 'Actualización de PluXml',
'L_WRONG_PHP_VERSION'					=> 'PluXml necesita PHP 5 o posterior.',

'L_SELECT_LANG'							=> 'Seleccione su idioma',
'L_INPUT_CHANGE'						=> 'Cambiar',

'L_UPDATE_UPTODATE'						=> 'Su PluXml ya está actualizado.',
'L_UPDATE_NOT_AVAILABLE'				=> 'No hay ninguna actualización disponible.',
'L_UPDATE_BACK'							=> 'Volver al sitio',
'L_UPDATE_WARNING1'						=> 'Va a actualizar su versión antigua de PluXml',
'L_UPDATE_SELECT_VERSION'				=> 'Selecccione la versión antigua de PluXml para actualizar.',
'L_UPDATE_WARNING2'						=> 'Si no encuentra su versión antigua en esta lista, es que no existe un proceso automático de actualización desde dicha versión por ser demasiado anitgua.<br />Le sugerimos que descargue la última versión de <a href="http://www.pluxml.org">PluXml</a> y realice una nueva instalación.',
'L_UPDATE_WARNING3'						=> 'Advertencia: antes de iniciar una actualización, no olvide hacer un respaldo de sus datos haciendo una copia de la carpeta «data»',
'L_UPDATE_START'						=> 'Inciar la actualización',

'L_UPDATE_ENDED'						=> 'Actualización finalizada',
'L_UPDATE_INPROGRESS'					=> 'Actualizando la versión',
'L_UPDATE_ERROR'						=> 'Ocurrió un error durante la actualización.',
'L_UPDATE_SUCCESSFUL'					=> '¡Se completaron correctamente todas las actualizaciones!',

'L_UPDATE_UPDATE_PARAMETERS_FILE'		=> 'Actualización del archivo «parametres.xml»',
'L_UPDATE_CREATE_TAGS_FILE'				=> 'Creación del archivo «tags.xml»',
'L_UPDATE_ERR_CREATE_TAGS_FILE'			=> 'Error al crear el archivo «tags.xml»',
'L_UPDATE_CREATE_THEME_FILE'			=> 'Creación del archivo de tema',
'L_UPDATE_ERR_CREATE_THEME_FILE'		=> 'Error al crear el archivo',
'L_UPDATE_ARTICLES_CONVERSION'			=> 'Conversión de los artículos al nuevo formato',
'L_UPDATE_ERR_FILE_PROCESSING'			=> 'Error al procesar el archivo',
'L_UPDATE_STATICS_MIGRATION'			=> 'Actualización del archivo de páginas estáticas',
'L_UPDATE_ERR_STATICS_MIGRATION'		=> 'Error al actualizar el archivo de páginas estáticas',
'L_UPDATE_CREATE_USERS_FILE'			=> 'Creación del archivo de usuarios',
'L_UPDATE_ERR_CREATE_USERS_FILE'		=> 'Error al crear el archivo de usuarios',
'L_UPDATE_USERS_MIGRATION'				=> 'Actualización del archivo de usuarios',
'L_UPDATE_ERR_USERS_MIGRATION'			=> 'Error al actualizar el archivo de usuarios',
'L_UPDATE_ERR_NO_USERS'					=> 'No se encontraron usuarios en el archivo',
'L_UPDATE_CREATE_HTACCESS_FILE'			=> 'Creación del archivo «.htaccess»',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'		=> 'Error al crear el archivo «.htaccess»',
'L_UPDATE_UPDATE_HTACCESS_FILE'			=> 'Actualización del archivo «.htaccess»',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'		=> 'Error al actualizar el archivo «.htaccess»',
'L_UPDATE_CATEGORIES_MIGRATION'			=> 'Actualización del archivo de categorías',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'		=> 'Error al actualizar el archivo de categorías',
'L_UPDATE_CREATE_PLUGINS_FILE'			=> 'Creación del archivo «plugins.xml»',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'		=> 'Error al crear el archivo «plugins.xml»',
'L_UPDATE_DELETE_FULLSCREEN_FILE'		=> 'Eliminación del archivo «core/admin/fullscreen.php»',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'	=> 'Error al eliminar el archivo «core/admin/fullscreen.php»',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'		=> 'Eliminación de la carpeta «core/plxtoolbar/»',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Error al eliminar la carpeta «core/plxtoolbar/»',
'L_UPDATE_FILE'							=> 'Actualizando archivo',
'L_UPDATE_ERR_FILE'						=> 'Error al actualizar archivo',
'L_UPDATE_PLUG_MOVEPARAMFILE'			=> 'Actualización de archivos de parámetros de complementos en la carpeta de configuración',
'L_UPDATE_UPDATE_PLUGINS_FILE'			=> 'Actualización del archivo «plugins.xml»',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/es/update.php <==
<?php

$LANG = array(

'L_SAVE_SUCCESSFUL'						=> 'Se guardaron los datos correctamente',
'L_UPDATE_TITLE'						=> 'Actualización de PluXml',
'L_WRONG_PHP_VERSION'					=> 'PluXml necesita PHP 5 o posterior.',

'L_SELECT_LANG'							=> 'Seleccione su idioma',
'L_INPUT_CHANGE'						=> 'Cambiar',

'L_UPDATE_UPTODATE'						=> 'Su PluXml ya está actualizado.',
'L_UPDATE_NOT_AVAILABLE'				=> 'No hay ninguna actualización disponible.',
'L_UPDATE_BACK'							=> 'Volver al sitio',
'L_UPDATE_WARNING1'						=> 'Va a actualizar su versión antigua de PluXml',
'L_UPDATE_SELECT_VERSION'				=> 'Selecccione la versión antigua de PluXml para actualizar.',
'L_UPDATE_WARNING2'						=> 'Si no encuentra su versión antigua en esta lista, es que no existe un proceso automático de actualización desde dicha versión por ser demasiado anitgua.<br />Le sugerimos que descargue la última versión de <a href="http://www.pluxml.org">PluXml</a> y realice una nueva instalación.',
'L_UPDATE_WARNING3'						=> 'Advertencia: antes de iniciar una actualización, no olvide hacer un respaldo de sus datos haciendo una copia de la carpeta «data»',
'L_UPDATE_START'						=> 'Inciar la actualización',

'L_UPDATE_ENDED'						=> 'Actualización finalizada',
'L_UPDATE_INPROGRESS'					=> 'Actualizando la versión',
'L_UPDATE_ERROR'						=> 'Ocurrió un error durante la actualización.',
'L_UPDATE_SUCCESSFUL'					=> '¡Se completaron correctamente todas las actualizaciones!',

'L_UPDATE_UPDATE_PARAMETERS_FILE'		=> 'Actualización del archivo «parametres.xml»',
'L_UPDATE_CREATE_TAGS_FILE'				=> 'Creación del archivo «tags.xml»',
'L_UPDATE_ERR_CREATE_TAGS_FILE'			=> 'Error al crear el archivo «tags.xml»',
'L_UPDATE_CREATE_THEME_FILE'			=> 'Creación del archivo de tema',
'L_UPDATE_ERR_CREATE_THEME_FILE'		=> 'Error al crear el archivo',
'L_UPDATE_ARTICLES_CONVERSION'			=> 'Conversión de los artículos al nuevo formato',
'L_UPDATE_ERR_FILE_PROCESSING'			=> 'Error al procesar el archivo',
'L_UPDATE_STATICS_MIGRATION'			=> 'Actualización del archivo de páginas estáticas',
'L_UPDATE_ERR_STATICS_MIGRATION'		=> 'Error al actualizar el archivo de páginas estáticas',
'L_UPDATE_CREATE_USERS_FILE'			=> 'Creación del archivo de usuarios',
'L_UPDATE_ERR_CREATE_USERS_FILE'		=> 'Error al crear el archivo de usuarios',
'L_UPDATE_USERS_MIGRATION'				=> 'Actualización del archivo de usuarios',
'L_UPDATE_ERR_USERS_MIGRATION'			=> 'Error al actualizar el archivo de usuarios',
'L_UPDATE_ERR_NO_USERS'					=> 'No se encontraron usuarios en el archivo',
'L_UPDATE_CREATE_HTACCESS_FILE'			=> 'Creación del archivo «.htaccess»',
'L_UPDATE_ERR_CREATE_HTACCESS_FILE'		=> 'Error al crear el archivo «.htaccess»',
'L_UPDATE_UPDATE_HTACCESS_FILE'			=> 'Actualización del archivo «.htaccess»',
'L_UPDATE_ERR_UPDATE_HTACCESS_FILE'		=> 'Error al actualizar el archivo «.htaccess»',
'L_UPDATE_CATEGORIES_MIGRATION'			=> 'Actualización del archivo de categorías',
'L_UPDATE_ERR_CATEGORIES_MIGRATION'		=> 'Error al actualizar el archivo de categorías',
'L_UPDATE_CREATE_PLUGINS_FILE'			=> 'Creación del archivo «plugins.xml»',
'L_UPDATE_ERR_CREATE_PLUGINS_FILE'		=> 'Error al crear el archivo «plugins.xml»',
'L_UPDATE_DELETE_FULLSCREEN_FILE'		=> 'Eliminación del archivo «core/admin/fullscreen.php»',
'L_UPDATE_ERR_DELETE_FULLSCREEN_FILE'	=> 'Error al eliminar el archivo «core/admin/fullscreen.php»',
'L_UPDATE_DELETE_PLXTOOLBAR_FOLDER'		=> 'Eliminación de la carpeta «core/plxtoolbar/»',
'L_UPDATE_ERR_DELETE_PLXTOOLBAR_FOLDER' => 'Error al eliminar la carpeta «core/plxtoolbar/»',
'L_UPDATE_FILE'							=> 'Actualizando archivo',
'L_UPDATE_ERR_FILE'						=> 'Error al actualizar archivo',
'L_UPDATE_PLUG_MOVEPARAMFILE'			=> 'Actualización de archivos de parámetros de complementos en la carpeta de configuración',
'L_UPDATE_UPDATE_PLUGINS_FILE'			=> 'Actualización del archivo «plugins.xml»',
'L_UPDATE_COMMENTS_MIGRATION'			=> 'Comentarios de migración',
'L_UPDATE_ERR_COMMENTS_MIGRATION'		=> 'Error al migrar comentarios',
);
?>
